(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17712,        716]*)
(*NotebookOutlinePosition[     18580,        744]*)
(*  CellTagsIndexPosition[     18536,        740]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Software and Calculations", "Section"],

Cell[TextData[{
  "(Some of the calculations in this notebook look different from those in \
the text because of\nlast minute changes in the software).\n\nFor computing \
cosets there are functions  ",
  StyleBox["LeftCosets",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  and ",
  StyleBox["RightCosets",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  . They take as arguments a group G and a subgroup K and produce a list \
of the elements of G partitioned into cosets with K itself as the first \
coset. To illustrate, let's repeat example 10.1. We have"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A4\  = \ Group[P[{1, 2, 3}], \ P[{2, 3, 4}]]\)], "Input"],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2 3)", "(2 3 4)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell["and ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(V\  = \ Group[P[{1, 2}, {3, 4}]\ , \ P[{1, 3}, {2, 4}]]\)], "Input"],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2)(3 4)", 
      "(1 3)(2 4)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell["Then", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftCosets[A4, V]\)], "Input"],

Cell[BoxData[
    \({{"(1)", "(1 2)(3 4)", "(1 3)(2 4)", "(1 4)(2 3)"}, {"(1 2 3)", 
        "(1 3 4)", "(1 4 2)", "(2 4 3)"}, {"(1 2 4)", "(1 3 2)", "(1 4 3)", 
        "(2 3 4)"}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If you only want a representative from each coset you can use   ",
  StyleBox["LeftCosetReps",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  or  \n",
  StyleBox["RightCosetReps",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftCosetReps[A4, V]\)], "Input"],

Cell[BoxData[
    \({"(1)", "(1 2 3)", "(1 2 4)"}\)], "Output"]
}, Open  ]],

Cell["\<\
These are just the first elements from each coset. We can check \
that V satisfies 10.3(i) by
computing its right cosets and comparing them with the left cosets:\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RightCosets[A4, V]\)], "Input"],

Cell[BoxData[
    \({{"(1)", "(1 2)(3 4)", "(1 3)(2 4)", "(1 4)(2 3)"}, {"(1 3 2)", 
        "(1 4 3)", "(1 2 4)", "(2 3 4)"}, {"(1 4 2)", "(1 2 3)", "(1 3 4)", 
        "(2 4 3)"}}\)], "Output"]
}, Open  ]],

Cell["So you can multiply two cosets together to get a third:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({P[{1, \ 2, \ 3}], P[{1, \ 3, \ 4}], \ P[{1, \ 4, \ 2}], \ 
        P[{2, \ 4, \ 3}]}\  . \ {P[{1, \ 2, \ 4}], \ P[{1, \ 3, \ 2}], \ 
        P[{1, \ 4, \ 3}], \ P[{2, \ 3, \ 4}]}\)], "Input"],

Cell[BoxData[
    \({"(1)", "(1 2)(3 4)", "(1 3)(2 4)", "(1 4)(2 3)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We can also verify that V is normal in ",
  Cell[BoxData[
      \(TraditionalForm\`A\_4\)]],
  " by calculating its conjugates. First we have\nthe function   ",
  StyleBox["Conjugate[a,b]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " which conjugates ",
  StyleBox["b",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " . For example, if"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a\  = \ P[{1, 2, 3}]\)], "Input"],

Cell[BoxData[
    \("(1 2 3)"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\  = \ P[{1, 4}]\)], "Input"],

Cell[BoxData[
    \("(1 4)"\)], "Output"]
}, Open  ]],

Cell["then", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Conjugate[a, b]\)], "Input"],

Cell[BoxData[
    \("(2 4)"\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "You can conjugate all the elements of a set by ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at once: "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Conjugate[\ a, Elements[V]\ ]\)], "Input"],

Cell[BoxData[
    \({"(1)", "(1 4)(2 3)", "(1 2)(3 4)", "(1 3)(2 4)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "which confirms that ",
  StyleBox["V",
    FontSlant->"Italic"],
  " is normal in ",
  Cell[BoxData[
      \(TraditionalForm\`A\_4\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["Example 10.5", "Subsection"],

Cell[TextData[{
  "In ",
  Cell[BoxData[
      \(TraditionalForm\`S\_5\)]],
  " we have the subgroup ",
  Cell[BoxData[
      \(TraditionalForm\`F\_20\)]],
  "(see exercise 8.19):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(F20\  = \ Group[P[{1, 2, 3, 4, 5}]\ , \ P[{1, 2, 4, 3}]]\)], "Input"],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2 3 4 5)", 
      "(1 2 4 3)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "A pair of generators of ",
  Cell[BoxData[
      \(TraditionalForm\`S\_5\)]],
  " is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(a\  = \ P[{1, 2, 3, 4, 5}]\), "\n", 
    \(b\  = \ P[{1, 2}]\)}], "Input"],

Cell[BoxData[
    \("(1 2 3 4 5)"\)], "Output"],

Cell[BoxData[
    \("(1 2)"\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To check whether ",
  Cell[BoxData[
      \(TraditionalForm\`F\_20\)]],
  " is normal in ",
  Cell[BoxData[
      \(TraditionalForm\`S\_5\)]],
  " you conjugate the generators of ",
  Cell[BoxData[
      \(TraditionalForm\`F\_20\)]],
  " first by ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and then by ",
  StyleBox["b",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and look whether the resulting sets lie in ",
  Cell[BoxData[
      \(TraditionalForm\`F\_20\)]],
  ". In fact since ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " belongs to ",
  Cell[BoxData[
      \(TraditionalForm\`F\_20\)]],
  " you need only check"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Conjugate[b, Generators[F20]]\)], "Input"],

Cell[BoxData[
    \({"(1 3 4 5 2)", "(1 4 3 2)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "which does not lie in ",
  Cell[BoxData[
      \(TraditionalForm\`F\_20\)]],
  ". So  ",
  Cell[BoxData[
      \(TraditionalForm\`F\_20\)]],
  " is not normal. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 10.6", "Subsection"],

Cell[TextData[{
  "\tLet ",
  Cell[BoxData[
      \(TraditionalForm\`G\_72\)]],
  " (see exercise 8.16) be the permutation group"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(G72\  = \ 
      Group[\ P[{1, 2, 3}]\ , \ P[{1, 4}, {2, 5}, {3, 6}]\ , \ 
        P[{1, 5, 2, 4}, {3, 6}]\ ]\)], "Input"],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2 3)", "(1 4)(2 5)(3 6)", 
      "(1 5 2 4)(3 6)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`G\_72\)]],
  " has order 72:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Order[G72]\)], "Input"],

Cell[BoxData[
    \(72\)], "Output"]
}, Open  ]],

Cell["Let K be the subgroup", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(K\  = \ Group[\ P[{1, 2, 3}]\ , \ P[{4, \ 5, 6}]\ ]\)], "Input"],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2 3)", "(4 5 6)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since these two 3-cycles commute with one another, \n\n\t\t\t\t\tK \
\[TildeFullEqual]  \[DoubleStruckCapitalZ]/3\[DoubleStruckCapitalZ] \[Cross] \
\[DoubleStruckCapitalZ]/3\[DoubleStruckCapitalZ]. \n\nThe first element of \
the list of generators of ",
  Cell[BoxData[
      \(TraditionalForm\`G\_72\)]],
  " is also a generator of ",
  StyleBox["K",
    FontFamily->"Courier",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  ". So to check that \nK \[LeftTriangle] ",
  Cell[BoxData[
      \(TraditionalForm\`G\_72\)]],
  "  we need only conjugate the generators of ",
  StyleBox["K",
    FontSlant->"Italic"],
  " by the remaining two generators of ",
  Cell[BoxData[
      \(TraditionalForm\`G\_72\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Conjugate[\ P[{1, 4}, {2, 5}, {3, 6}]\ , \ Generators[K]]\), "\n", 
    \(Conjugate[\ P[{1, 5, 2, 4}, {3, 6}]\ , \ Generators[K]]\)}], "Input"],

Cell[BoxData[
    \({"(4 5 6)", "(1 2 3)"}\)], "Output"],

Cell[BoxData[
    \({"(4 6 5)", "(1 2 3)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Therefore K is a normal subgroup of ",
  Cell[BoxData[
      \(TraditionalForm\`G\_72\)]],
  ". The quotient group  L := ",
  Cell[BoxData[
      \(TraditionalForm\`G\_72\)]],
  "/ K  has order  72/9=8 . We want to determine which group of order 8 it \
is. Since each coset has 9 elements, we will tell ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " not to print out the entire list of cosets when it computes L:"
}], "Text"],

Cell[BoxData[
    \(\(L\  = \ LeftCosets[G72, K];\)\)], "Input"],

Cell["First we look at representatives from each of the cosets.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftCosetReps[G72, K]\)], "Input"],

Cell[BoxData[
    \({"(1)", "(1 2)", "(4 5)", "(1 4 2 5 3 6)", "(1 4 2 6 3 5)", 
      "(1 2)(4 5)", "(1 4)(2 5 3 6)", "(1 4)(2 6 3 5)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The first coset, ",
  StyleBox["L[[1]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", is K = ",
  Cell[BoxData[
      \(TraditionalForm\`1\_L\)]],
  ". The second,  ",
  StyleBox["L[[2]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = (1 2)K . Now\n\n\t\t\t\t\t",
  StyleBox["(",
    FontSize->13],
  " (1 ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{\(\(\(2\)\()\)\) K\), " ", 
            StyleBox[")",
              FontSize->13]}], "2"], TraditionalForm]]],
  " =  (1 ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2\)\()\)\)\^2\)]],
  "K  =  K .\n\nIn other words, it has order 2. Since the representatives of \
the cosets ",
  StyleBox["L[[3]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["L[[6]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " have order 2 as well, so do the cosets themselves. Now"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L[\([4]\)] . L[\([4]\)]\)], "Input"],

Cell[BoxData[
    \({"(1)", "(1 2 3)", "(1 3 2)", "(4 5 6)", "(4 6 5)", "(1 2 3)(4 5 6)", 
      "(1 2 3)(4 6 5)", "(1 3 2)(4 5 6)", "(1 3 2)(4 6 5)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "which is just ",
  StyleBox["L[[1]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L[\([5]\)] . L[\([5]\)]\)], "Input"],

Cell[BoxData[
    \({"(1)", "(1 2 3)", "(1 3 2)", "(4 5 6)", "(4 6 5)", "(1 2 3)(4 5 6)", 
      "(1 2 3)(4 6 5)", "(1 3 2)(4 5 6)", "(1 3 2)(4 6 5)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "as well. So ",
  StyleBox["L[[4]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and",
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["L[[5]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " also have order 2. This leaves ",
  StyleBox["L[[7]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["L[[8]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". We can see that\n\n\t\t\t\t",
  StyleBox["(",
    FontSize->13],
  " (1 4)(2 5 3 6)",
  Cell[BoxData[
      \(TraditionalForm\`)\^\(-1\)\)]],
  " =  (1 4)(2 6 3 5) .\n\nSo these two are inverse to each other. Do they in \
fact have order 4 ?"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L[\([7]\)] . L[\([7]\)]\)], "Input"],

Cell[BoxData[
    \({"(1 2)(4 5)", "(1 2)(4 6)", "(1 2)(5 6)", "(1 3)(4 5)", "(1 3)(4 6)", 
      "(1 3)(5 6)", "(2 3)(4 5)", "(2 3)(4 6)", "(2 3)(5 6)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Comparing this with our list of coset representatives, we see that this \
must be  ",
  StyleBox["L[[6]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ,\nwhich has order 2. So  ",
  StyleBox["L[[6]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = ",
  StyleBox["L",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[\([\([7]\)]\),
            FontFamily->"Courier",
            FontWeight->"Bold"], "2"], TraditionalForm]]],
  " and  ",
  StyleBox["L[[8]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[\(L[\([7]\)]\),
            FontFamily->"Courier",
            FontWeight->"Bold"], "3"], TraditionalForm]]],
  ". It begins to look as if L might be isomorphic to ",
  Cell[BoxData[
      \(TraditionalForm\`D\_4\)]],
  "(see equation (7.1)). To check this, we need\ngenerators \[Sigma] and \
\[Tau] satisfying"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^4\)]],
  " = 1    ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\^2\)]],
  " = 1    \[Tau]\[Sigma] = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Sigma]\^\(-1\)\) \[Tau]\)]],
  "  ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  " Let's try   \[Sigma] =  ",
  StyleBox["L[[7]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and  \[Tau] = ",
  StyleBox["L[[2]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Courier"],
  " To see that they generate ",
  StyleBox["L",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " we compute"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(L[\([2]\)] . L[\([7]\)]\), "\n", 
    \(L[\([2]\)] . L[\([6]\)]\), "\n", 
    \(L[\([2]\)] . L[\([8]\)]\)}], "Input"],

Cell[BoxData[
    \({"(1 4 2 5 3 6)", "(1 4 3 6 2 5)", "(1 5 2 6 3 4)", "(1 5 3 4 2 6)", 
      "(1 6 2 4 3 5)", "(1 6 3 5 2 4)", "(1 4)(2 5)(3 6)", "(1 5)(2 6)(3 4)", 
      "(1 6)(2 4)(3 5)"}\)], "Output"],

Cell[BoxData[
    \({"(4 5)", "(4 6)", "(5 6)", "(1 2 3)(4 5)", "(1 2 3)(4 6)", 
      "(1 2 3)(5 6)", "(1 3 2)(4 5)", "(1 3 2)(4 6)", 
      "(1 3 2)(5 6)"}\)], "Output"],

Cell[BoxData[
    \({"(1 4 2 6 3 5)", "(1 4 3 5 2 6)", "(1 5 2 4 3 6)", "(1 5 3 6 2 4)", 
      "(1 6 2 5 3 4)", "(1 6 3 4 2 5)", "(1 4)(2 6)(3 5)", "(1 5)(2 4)(3 6)", 
      "(1 6)(2 5)(3 4)"}\)], "Output"]
}, Open  ]],

Cell["Thus", "Text"],

Cell[TextData[{
  StyleBox["L[[2]] . L[[7]]  =  L[[4]]\nL[[2]] . ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{
            StyleBox["L",
              FontSlant->"Plain"], " ", "[", \([7]\), "]"}], "2"], 
        TraditionalForm]],
    FontWeight->"Bold"],
  StyleBox["  =  L[[2]] . L[[6]]  =  L[[3]]\nL[[2]] . ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{
            StyleBox["L",
              FontSlant->"Plain"], " ", "[", \([7]\), "]"}], "3"], 
        TraditionalForm]],
    FontWeight->"Bold"],
  StyleBox["  =  L[[2]] . L[[8]]  =  L[[5]] .",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "So  ",
  StyleBox["L[[7]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and   ",
  StyleBox["L[[2]] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "do generate ",
  StyleBox["L",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Now let's see whether they satisfy the right\nrelation. We must check \
whether "
}], "Text"],

Cell[TextData[{
  StyleBox["L",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\([\([7]\)]\)\^\(-1\)\)],
    FontWeight->"Bold"],
  StyleBox[".L[[2]] = L[[8]].L[[2]] = L[[4]]  :",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\n\)\(L[\([8]\)] . L[\([2]\)]\)\)\)], "Input"],

Cell[BoxData[
    \({"(1 4 2 5 3 6)", "(1 4 3 6 2 5)", "(1 5 2 6 3 4)", "(1 5 3 4 2 6)", 
      "(1 6 2 4 3 5)", "(1 6 3 5 2 4)", "(1 4)(2 5)(3 6)", "(1 5)(2 6)(3 4)", 
      "(1 6)(2 4)(3 5)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "which is ",
  StyleBox["L[[4]]",
    FontWeight->"Bold"],
  ". So indeed"
}], "Text"],

Cell[TextData[{
  "L ",
  Cell[BoxData[
      \(TraditionalForm\`\( \[TildeFullEqual] D\_4\)\)]]
}], "Text",
  TextAlignment->Center]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
CellGrouping->Manual,
WindowSize->{524, 719},
WindowMargins->{{Automatic, 105}, {46, Automatic}},
MacintoshSystemPageSetup->"\<\
02P0001804P000000^L2D_ogooL33`9K8085:0?l0000005X0FP000003X<;VP5d
038;VTRX04/00@4100000@0100400@000000000000000000000000000040I0<0
000000000010<0D08P000000000eC64P\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 44, 0, 50, "Section"],
Cell[1764, 51, 590, 14, 111, "Text"],

Cell[CellGroupData[{
Cell[2379, 69, 77, 1, 27, "Input"],
Cell[2459, 72, 93, 1, 26, "Output"]
}, Open  ]],
Cell[2567, 76, 20, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[2612, 80, 88, 1, 27, "Input"],
Cell[2703, 83, 106, 2, 26, "Output"]
}, Open  ]],
Cell[2824, 88, 20, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[2869, 92, 50, 1, 27, "Input"],
Cell[2922, 95, 195, 3, 56, "Output"]
}, Open  ]],
Cell[3132, 101, 278, 10, 48, "Text"],

Cell[CellGroupData[{
Cell[3435, 115, 53, 1, 27, "Input"],
Cell[3491, 118, 63, 1, 26, "Output"]
}, Open  ]],
Cell[3569, 122, 187, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[3781, 131, 51, 1, 27, "Input"],
Cell[3835, 134, 195, 3, 56, "Output"]
}, Open  ]],
Cell[4045, 140, 71, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[4141, 144, 212, 3, 59, "Input"],
Cell[4356, 149, 83, 1, 26, "Output"]
}, Open  ]],
Cell[4454, 153, 465, 17, 47, "Text"],

Cell[CellGroupData[{
Cell[4944, 174, 53, 1, 27, "Input"],
Cell[5000, 177, 43, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5080, 183, 50, 1, 27, "Input"],
Cell[5133, 186, 41, 1, 26, "Output"]
}, Open  ]],
Cell[5189, 190, 20, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[5234, 194, 48, 1, 27, "Input"],
Cell[5285, 197, 41, 1, 26, "Output"]
}, Open  ]],
Cell[5341, 201, 163, 6, 31, "Text"],

Cell[CellGroupData[{
Cell[5529, 211, 62, 1, 27, "Input"],
Cell[5594, 214, 83, 1, 26, "Output"]
}, Open  ]],
Cell[5692, 218, 172, 8, 32, "Text"],

Cell[CellGroupData[{
Cell[5889, 230, 34, 0, 46, "Subsection"],
Cell[5926, 232, 192, 8, 30, "Text"],

Cell[CellGroupData[{
Cell[6143, 244, 89, 1, 27, "Input"],
Cell[6235, 247, 106, 2, 26, "Output"]
}, Open  ]],
Cell[6356, 252, 116, 5, 30, "Text"],

Cell[CellGroupData[{
Cell[6497, 261, 95, 2, 43, "Input"],
Cell[6595, 265, 47, 1, 26, "Output"],
Cell[6645, 268, 41, 1, 26, "Output"]
}, Open  ]],
Cell[6701, 272, 722, 29, 64, "Text"],

Cell[CellGroupData[{
Cell[7448, 305, 62, 1, 27, "Input"],
Cell[7513, 308, 62, 1, 26, "Output"]
}, Open  ]],
Cell[7590, 312, 192, 8, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7819, 325, 34, 0, 46, "Subsection"],
Cell[7856, 327, 141, 5, 30, "Text"],

Cell[CellGroupData[{
Cell[8022, 336, 142, 3, 43, "Input"],
Cell[8167, 341, 126, 2, 26, "Output"]
}, Open  ]],
Cell[8308, 346, 98, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[8431, 354, 43, 1, 27, "Input"],
Cell[8477, 357, 36, 1, 26, "Output"]
}, Open  ]],
Cell[8528, 361, 37, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[8590, 365, 84, 1, 27, "Input"],
Cell[8677, 368, 93, 1, 26, "Output"]
}, Open  ]],
Cell[8785, 372, 769, 22, 113, "Text"],

Cell[CellGroupData[{
Cell[9579, 398, 164, 2, 43, "Input"],
Cell[9746, 402, 56, 1, 26, "Output"],
Cell[9805, 405, 56, 1, 26, "Output"]
}, Open  ]],
Cell[9876, 409, 456, 12, 66, "Text"],
Cell[10335, 423, 64, 1, 27, "Input"],
Cell[10402, 426, 73, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[10500, 430, 54, 1, 27, "Input"],
Cell[10557, 433, 150, 2, 41, "Output"]
}, Open  ]],
Cell[10722, 438, 934, 35, 113, "Text"],

Cell[CellGroupData[{
Cell[11681, 477, 56, 1, 27, "Input"],
Cell[11740, 480, 164, 2, 41, "Output"]
}, Open  ]],
Cell[11919, 485, 130, 6, 31, "Text"],

Cell[CellGroupData[{
Cell[12074, 495, 56, 1, 27, "Input"],
Cell[12133, 498, 164, 2, 41, "Output"]
}, Open  ]],
Cell[12312, 503, 685, 27, 113, "Text"],

Cell[CellGroupData[{
Cell[13022, 534, 56, 1, 27, "Input"],
Cell[13081, 537, 167, 2, 41, "Output"]
}, Open  ]],
Cell[13263, 542, 1035, 36, 80, "Text"],
Cell[14301, 580, 293, 11, 30, "Text"],
Cell[14597, 593, 386, 16, 31, "Text"],

Cell[CellGroupData[{
Cell[15008, 613, 138, 3, 59, "Input"],
Cell[15149, 618, 207, 3, 56, "Output"],
Cell[15359, 623, 171, 3, 41, "Output"],
Cell[15533, 628, 207, 3, 56, "Output"]
}, Open  ]],
Cell[15755, 634, 20, 0, 30, "Text"],
Cell[15778, 636, 723, 24, 68, "Text"],
Cell[16504, 662, 370, 15, 47, "Text"],
Cell[16877, 679, 259, 9, 32, "Text"],

Cell[CellGroupData[{
Cell[17161, 692, 70, 1, 43, "Input"],
Cell[17234, 695, 207, 3, 56, "Output"]
}, Open  ]],
Cell[17456, 701, 104, 5, 32, "Text"],
Cell[17563, 708, 133, 5, 30, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

