(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7741,        287]*)
(*NotebookOutlinePosition[      8613,        315]*)
(*  CellTagsIndexPosition[      8569,        311]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Chapter 11: A  Calculation", "Section"],

Cell[TextData[{
  "Let's look at the Sylow subgroups of ",
  Cell[BoxData[
      \(TraditionalForm\`S\_8\)]],
  ". First factor 8! ."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->14],

Cell[CellGroupData[{

Cell[TextData[StyleBox["FactorInteger[8!]",
  AspectRatioFixed->True,
  FontFamily->"courier"]], "Input",
  AspectRatioFixed->True,
  FontSize->14],

Cell[BoxData[
    \({{2, 7}, {3, 2}, {5, 1}, {7, 1}}\)], "Output"]
}, Open  ]],

Cell["In other words", "Text",
  FontSize->14],

Cell[TextData[{
  "8! = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(2\^7\),
            "TraditionalForm"], \(3\^2\)}], TraditionalForm]]],
  "5 7"
}], "Text",
  TextAlignment->Center,
  FontSize->14],

Cell[TextData[{
  StyleBox["The Sylow 5-subgroups and Sylow 7-subgroups are cyclic, generated \
by 5-cycles and 7-cycles respectively. A Sylow 3-subgroup is generated by two \
disjoint 3-cycles. A Sylow 2-subgroup has order ",
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`2\^7\)]],
  "= ",
  StyleBox["128 and is harder to find. The order of any element in it is a \
power of 2. So let's begin our list of generators with an 8-cycle, say \n\n   \
                       ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" \t\t\t\t",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold"],
  StyleBox["(1 2 3 4 5 6 7 8)",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["\n\n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"courier",
    FontWeight->"Bold"],
  StyleBox["If we add an arbitrary 4-cycle we will get a group which is too \
big. Now the square of this 8-cycle is \n\t\t\t\t\t\t\t\n\t\t\t\t\t\t\t(1 3 5 \
7)(2 4 6 8)",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["\n\n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold"],
  StyleBox["So let's take",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["\n\t\t\t\t\t\t\t",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold"],
  StyleBox["(1 3 5 7)",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["\n\t\t\t\t\t\t\t\t\n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold"],
  StyleBox["as the second generator.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->14],

Cell[CellGroupData[{

Cell[TextData[StyleBox["H = Group[P[{1,2,3,4,5,6,7,8}], P[{1,3,5,7}]]",
  AspectRatioFixed->True,
  FontFamily->"courier"]], "Input",
  AspectRatioFixed->True,
  FontSize->14],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2 3 4 5 6 7 8)", 
      "(1 3 5 7)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Order[H]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(32\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["So we have to add another element to our list of generators. If \
we take an arbitrary 2-cycle we will get the whole group ",
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`S\_8\)]],
  StyleBox[". But the square of our 4-cycle is\n\n\t\t\t\t\t\t\t(1 5)(3 7) .",
    
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->14],

Cell[TextData[StyleBox["So let's add\n\n\t\t\t\t\t\t\t(1 5)\n\t\t\t\t\t\t\t\t\
\t\t\nto our set of generators.",
  Evaluatable->False,
  AspectRatioFixed->True]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->14],

Cell[CellGroupData[{

Cell[TextData[StyleBox["H = Group[P[{1,2,3,4,5,6,7,8}], P[{1,3,5,7}], \
P[{1,5}]]",
  AspectRatioFixed->True,
  FontFamily->"courier"]], "Input",
  FontSize->14],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2 3 4 5 6 7 8)", "(1 3 5 7)", 
      "(1 5)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Order[H]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(128\)], "Output"]
}, Open  ]],

Cell["We have found a 2-Sylow subgroup!", "Text",
  Evaluatable->False,
  FontSize->14],

Cell[TextData[{
  StyleBox["\tTheorem 11.2 and Corollary 11.1 tell us that the number of \
Sylow 2-subgroups is odd and divides 8!/128 = 315. It would be helpful to \
know how many there really are. By the second Sylow theorem (Theorem 11.3) \
all Sylow 2-subgroups are conjugate to one another. So we must determine the \
number of subgroups of ",
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`S\_8\)]],
  StyleBox[" conjugate to our subgroup ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["H",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold"],
  StyleBox[". The function  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["NumberOf",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Conjugates",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["  will do this. An 8-cycle and a transposition generate ",
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\_8\)\(:\)\)\)]]
}], "Text",
  Evaluatable->False,
  FontSize->14],

Cell[CellGroupData[{

Cell[TextData[StyleBox["S8 = Group[ P[{1,2,3,4,5,6,7,8}], P[{1,2}] ]",
  AspectRatioFixed->True,
  FontFamily->"courier"]], "Input",
  FontSize->14],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2 3 4 5 6 7 8)", 
      "(1 2)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell["Then", "Text",
  Evaluatable->False,
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberOfConjugates[S8, \ H]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(315\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
AutoGeneratedPackage->None,
WindowSize->{606, 778},
WindowMargins->{{Automatic, 14}, {Automatic, 1}},
MacintoshSystemPageSetup->"\<\
02P0001804P000000^L2D_ogooL33`9K8085:0?l0000005X0FP000003X<;VP5d
038;VTRX04/00@4100000@0100400@000000000000000000000000000040I0<0
000000000010<0D08P000000000eC64P\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 45, 0, 50, "Section"],
Cell[1787, 53, 209, 8, 32, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2021, 65, 147, 4, 28, "Input"],
Cell[2171, 71, 66, 1, 26, "Output"]
}, Open  ]],
Cell[2252, 75, 46, 1, 32, "Text"],
Cell[2301, 78, 227, 10, 32, "Text"],
Cell[2531, 90, 1749, 55, 310, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4305, 149, 175, 4, 28, "Input"],
Cell[4483, 155, 112, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4632, 162, 57, 2, 28, "Input"],
Cell[4692, 166, 36, 1, 26, "Output"]
}, Open  ]],
Cell[4743, 170, 469, 14, 86, "Text",
  Evaluatable->False],
Cell[5215, 186, 234, 6, 104, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5474, 196, 161, 4, 28, "Input"],
Cell[5638, 202, 121, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5796, 209, 57, 2, 28, "Input"],
Cell[5856, 213, 37, 1, 26, "Output"]
}, Open  ]],
Cell[5908, 217, 87, 2, 32, "Text",
  Evaluatable->False],
Cell[5998, 221, 1217, 37, 106, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[7240, 262, 148, 3, 28, "Input"],
Cell[7391, 267, 108, 2, 26, "Output"]
}, Open  ]],
Cell[7514, 272, 58, 2, 32, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[7597, 278, 76, 2, 28, "Input"],
Cell[7676, 282, 37, 1, 26, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

