(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5275,        198]*)
(*NotebookOutlinePosition[      6120,        225]*)
(*  CellTagsIndexPosition[      6076,        221]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Chapter 15: Software", "Section",
  FontSize->14],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a package SymmetricPolynomials.m with a function ",
  StyleBox["SymmetricReduction",
    FontWeight->"Bold"],
  "\nwhich implements the algorithm in theorem 15.1. It requires that you \
list the variables in your symmetric polynomial, and name the elementary \
symmetric polynomials. First load the package:"
}], "Text",
  FontSize->14],

Cell[BoxData[
    \(<< Algebra`SymmetricPolynomials`\)], "Input",
  FontSize->14],

Cell[TextData[{
  "Here is ",
  Cell[BoxData[
      \(TraditionalForm\`p\_3\)]],
  "in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_\(\(2\)\(\ \)\)\)]],
  "and  ",
  Cell[BoxData[
      \(TraditionalForm\`s\_3\)]],
  ":"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SymmetricReduction", "[", 
      StyleBox[\(u^3 + v^3 + w^3, {u, v, w}, {s1, s2, s3}\),
        FontFamily->"courier"], "]"}]], "Input",
  FontSize->14],

Cell[BoxData[
    \({s1\^3 - 3\ s1\ s2 + 3\ s3, 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Actually the function will take an arbitrary polynomial and write it as \
symmetric polynomial and a remainder. If you are only interested in symmetric \
polynomials, you can get rid of the zero remainder by applying the function \
",
  StyleBox["First",
    FontWeight->"Bold"],
  ":"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(First[%]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(s1\^3 - 3\ s1\ s2 + 3\ s3\)], "Output"]
}, Open  ]],

Cell["\<\
Here is the discriminant  \[CapitalDelta]  in four variables x1, \
x2, x3, x4, written in term of the elementary symmetric polynomials:\
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Delta = ((",
    FontFamily->"courier"],
  "x",
  StyleBox["1-",
    FontFamily->"courier"],
  "x",
  StyleBox["2)(",
    FontFamily->"courier"],
  "x",
  StyleBox["2-",
    FontFamily->"courier"],
  "x",
  StyleBox["3)(",
    FontFamily->"courier"],
  "x",
  StyleBox["3-",
    FontFamily->"courier"],
  "x",
  StyleBox["4)(",
    FontFamily->"courier"],
  "x",
  StyleBox["1-",
    FontFamily->"courier"],
  "x",
  StyleBox["3)(",
    FontFamily->"courier"],
  "x",
  StyleBox["2-",
    FontFamily->"courier"],
  "x",
  StyleBox["4)(",
    FontFamily->"courier"],
  "x",
  StyleBox["1-",
    FontFamily->"courier"],
  "x",
  StyleBox["4))^2",
    FontFamily->"courier"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \(\((x1 - x2)\)\^2\ \((x1 - x3)\)\^2\ \((x2 - x3)\)\^2\ \((x1 - x4)\)\^2\ \
\((x2 - x4)\)\^2\ \((x3 - x4)\)\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"First", "[", " ", 
      RowBox[{"SymmetricReduction", "[", " ", 
        StyleBox[\(Expand[Delta], {x1, x2, x3, x4}, {s1, s2, s3, s4}\),
          FontFamily->"courier"], 
        StyleBox[" ",
          FontFamily->"courier"], "]"}], " ", "]"}]], "Input",
  FontSize->14],

Cell[BoxData[
    \(s1\^2\ s2\^2\ s3\^2 - 4\ s2\^3\ s3\^2 - 4\ s1\^3\ s3\^3 + 
      18\ s1\ s2\ s3\^3 - 27\ s3\^4 - 4\ s1\^2\ s2\^3\ s4 + 16\ s2\^4\ s4 + 
      18\ s1\^3\ s2\ s3\ s4 - 80\ s1\ s2\^2\ s3\ s4 - 6\ s1\^2\ s3\^2\ s4 + 
      144\ s2\ s3\^2\ s4 - 27\ s1\^4\ s4\^2 + 144\ s1\^2\ s2\ s4\^2 - 
      128\ s2\^2\ s4\^2 - 192\ s1\ s3\ s4\^2 + 256\ s4\^3\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowSize->{646, 736},
WindowMargins->{{23, Automatic}, {Automatic, 38}},
MacintoshSystemPageSetup->"\<\
02P0001804P000000^L2D_ogooL33`9K8085:0?l0000005X0FP000003X<;VP5d
038;VTRX04/00@4100000@0100400@000000000000000000000000000040I0<0
000000000010<0D08P000000000eC64P\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 55, 1, 50, "Section"],
Cell[1797, 54, 412, 10, 70, "Text"],
Cell[2212, 66, 81, 2, 28, "Input"],
Cell[2296, 70, 318, 15, 32, "Text"],

Cell[CellGroupData[{
Cell[2639, 89, 179, 4, 28, "Input"],
Cell[2821, 95, 64, 1, 28, "Output"]
}, Open  ]],
Cell[2900, 99, 332, 9, 70, "Text"],

Cell[CellGroupData[{
Cell[3257, 112, 57, 2, 28, "Input"],
Cell[3317, 116, 59, 1, 28, "Output"]
}, Open  ]],
Cell[3391, 120, 210, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[3626, 130, 761, 41, 28, "Input"],
Cell[4390, 173, 142, 2, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4569, 180, 300, 7, 46, "Input"],
Cell[4872, 189, 375, 5, 62, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

