(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18015,        709]*)
(*NotebookOutlinePosition[     18859,        736]*)
(*  CellTagsIndexPosition[     18815,        732]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Chapter 3: Software and Calculations", "Section"],

Cell[TextData[{
  StyleBox["The package",
    FontSize->14,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" \"Groups.m\" can be used to make useful calculations in \
permutation groups. To start you must load it:",
    FontSize->14]
}], "Text",
  TextAlignment->Left,
  FontSize->16],

Cell[BoxData[
    StyleBox[\(<< Groups.m\),
      FontSize->14]], "Input"],

Cell[TextData[{
  StyleBox["Next you have to know how our notation for permutations is \
implemented. In this package a permutation (in mapping notation) is given by \
the list of its images with the header ",
    FontSize->14],
  StyleBox["M. ",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox[" For example",
    FontSize->14]
}], "Text",
  TextAlignment->Left,
  FontSize->16],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {"1", "2", "3", "4", "5", "6"},
            {"2", "4", "1", "6", "3", "5"}
            }], ")"}]],
    FontSize->14]
}], "Text",
  TextAlignment->Center,
  FontSize->16],

Cell[TextData[StyleBox["is represented by",
  FontSize->14]], "Text",
  TextAlignment->Left,
  FontSize->16],

Cell[TextData[StyleBox["M[2,4,1,6,3,5]",
  FontFamily->"Courier",
  FontSize->14,
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  FontSize->16],

Cell[TextData[StyleBox["You can name this permutation:",
  FontSize->14]], "Text",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["a",
        FontSize->14], 
      StyleBox[" ",
        FontSize->14], 
      StyleBox["=",
        FontSize->14], 
      StyleBox[" ",
        FontSize->14], 
      StyleBox[\(M[2, 4, 1, 6, 3, 5]\),
        FontFamily->"Courier",
        FontSize->14,
        FontWeight->"Bold"]}]], "Input",
  FontSize->16],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "3", "4", "5", "6"},
            {"2", "4", "1", "6", "3", "5"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["If  ",
    FontSize->14],
  StyleBox["b ",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox[" is another permutation then the product  ",
    FontSize->14],
  StyleBox["ab",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox["  is given by",
    FontSize->14]
}], "Text",
  FontSize->16],

Cell[TextData[StyleBox["a.b",
  FontFamily->"Courier",
  FontSize->14,
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  FontSize->16],

Cell[TextData[StyleBox["For example if",
  FontSize->14]], "Text",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(b\  = \ M[4, 2, 3, 6, 1, 5]\),
      FontSize->14]], "Input",
  FontSize->16],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "3", "4", "5", "6"},
            {"4", "2", "3", "6", "1", "5"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["then entering",
  FontSize->14]], "Text",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(a . b\)], "Input",
  FontSize->16],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "3", "4", "5", "6"},
            {"6", "4", "1", "5", "2", "3"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["To find the inverse of  ",
    FontSize->14],
  StyleBox["a ",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox[", enter",
    FontSize->14]
}], "Text",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(Inverse[a]\),
      FontSize->14]], "Input",
  FontSize->16],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "3", "4", "5", "6"},
            {"3", "1", "5", "2", "6", "4"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tA permutation in cycle notation is written as the list of its cycles, \
which are in turn lists, and is preceded by the header ",
  StyleBox["P",
    FontWeight->"Bold"],
  ". For example  (1 2)(3 4 5)  is represented by"
}], "Text",
  FontSize->14],

Cell[TextData[StyleBox[" P[{1,2},{3,4,5}]",
  FontFamily->"Courier",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  FontSize->14],

Cell["\<\
 You can take products and inverses using cycle notation just as \
with mapping notation:\
\>", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["P",
          FontSize->14], 
        StyleBox["[",
          FontFamily->"Courier",
          FontSize->14,
          FontWeight->"Bold"], 
        StyleBox[\({1, 2}, {3, 4, 5}\),
          FontFamily->"Courier",
          FontSize->14,
          FontWeight->"Bold"], 
        StyleBox["]",
          FontFamily->"Courier",
          FontSize->14,
          FontWeight->"Bold"]}], 
      StyleBox[".",
        FontFamily->"Courier",
        FontSize->14,
        FontWeight->"Bold"], 
      StyleBox[\(P[{1, 2, 3, 4, 5}]\),
        FontFamily->"Courier",
        FontSize->14,
        FontWeight->"Bold"]}]], "Input",
  FontSize->16],

Cell[BoxData[
    \("(2 4 3 5)"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[
      RowBox[{"Inverse", "[", 
        RowBox[{"P", 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\({1, 2}, {3, 4, 5}\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], "]"}],
      FontSize->14]], "Input",
  FontSize->16],

Cell[BoxData[
    \("(1 2)(3 5 4)"\)], "Output"]
}, Open  ]],

Cell["\<\
Output is in standard mathematical cycle notation.

\tYou can apply these functions to lists of permutations. When you take the \
product of two lists of permutations, the product of every permutation in the \
first list with every one in the second will be computed: for example\
\>", \
"Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b} . {a, b}\)], "Input",
  FontSize->14],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5", "6"},
                {"2", "6", "4", "5", "3", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5", "6"},
                {"4", "6", "2", "5", "1", "3"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5", "6"},
                {"6", "2", "3", "5", "4", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5", "6"},
                {"6", "4", "1", "5", "2", "3"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
These functions are useful for checking whether a set of \
permutations form a group. For example let\
\>", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(G\  = \ {M[2, 3, 1, 5, 4], \ M[4, 1, 2, 5, 3], \ M[1, 3, 5, 2, 4], \ 
        M[2, 1, 3, 4, 5], \ M[1, 2, 3, 4, 5]}\)], "Input",
  FontSize->14],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5"},
                {"2", "3", "1", "5", "4"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5"},
                {"4", "1", "2", "5", "3"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5"},
                {"1", "3", "5", "2", "4"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5"},
                {"2", "1", "3", "4", "5"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5"},
                {"1", "2", "3", "4", "5"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Inverse[G]\)], "Input",
  FontSize->14],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5"},
                {"3", "1", "2", "5", "4"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5"},
                {"2", "3", "5", "1", "4"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5"},
                {"1", "4", "2", "5", "3"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5"},
                {"2", "1", "3", "4", "5"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3", "4", "5"},
                {"1", "2", "3", "4", "5"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output"]
}, Open  ]],

Cell["So", "Text",
  FontSize->14],

Cell[TextData[{
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"1", "2", "3", "4", "5"},
              {"2", "3", "1", "5", "4"}
              }], "\[NoBreak]", ")"}], \(-1\)]]],
  "=  ",
  Cell[BoxData[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "3", "4", "5"},
            {"3", "1", "2", "5", "4"}
            }], "\[NoBreak]", ")"}]]],
  " "
}], "Text",
  TextAlignment->Center,
  FontSize->14],

Cell[TextData[{
  "is not in the set  ",
  StyleBox["G",
    FontWeight->"Bold"],
  "  and therefore  ",
  StyleBox["G",
    FontWeight->"Bold"],
  "  is not a permutation group."
}], "Text",
  FontSize->14],

Cell[TextData[{
  "The function  ",
  StyleBox["Group",
    FontWeight->"Bold"],
  "  calculates the permutation group generated by ",
  StyleBox["a given set of permutations.",
    FontVariations->{"CompatibilityType"->0}],
  " All computations take place in ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  " where ",
  StyleBox["n ",
    FontFamily->"cmti12",
    FontSize->14],
  " is the largest number occurring in the cycles in the input. The algorithm \
used is the one given in exercise 3.8. For example, the permutation group  ",
  StyleBox["G = <(1 2 3 4 5), (1 2)(3 5)>",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["  ",
    FontSlant->"Italic"],
  StyleBox["is given by",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(G = \ Group[\ P[{1, 2, 3, 4, 5}]\ , \ P[{1, 2}, {3, 5}]\ ]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2 3 4 5)", 
      "(1 2)(3 5)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To see a list of the elements in G, you use the function ",
  StyleBox["Elements",
    FontWeight->"Bold"],
  StyleBox[":",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Elements[G]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \({"(1)", "(1 2 3 4 5)", "(1 3 5 2 4)", "(1 4 2 5 3)", "(1 5 4 3 2)", 
      "(1 2)(3 5)", "(1 3)(4 5)", "(1 4)(2 3)", "(1 5)(2 4)", 
      "(2 5)(3 4)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["The function ",
    FontSize->16],
  StyleBox["Generators",
    FontSize->16,
    FontWeight->"Bold"],
  StyleBox[" will print out the generators of G again:",
    FontSize->16]
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(Generators[G]\),
      FontSize->16]], "Input",
  FontSize->14],

Cell[BoxData[
    \({"(1 2 3 4 5)", "(1 2)(3 5)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The order of the permutation group is given by the function  ",
  StyleBox["Order",
    FontWeight->"Bold"],
  " :"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Order[G]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(10\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We can verify by computation that ",
  StyleBox["(1 2)",
    FontVariations->{"CompatibilityType"->0}],
  " and ",
  StyleBox["(1 2 3 4 5 6)",
    FontVariations->{"CompatibilityType"->0}],
  " generate ",
  Cell[BoxData[
      \(TraditionalForm\`S\_6\)]],
  ":"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Order[\ Group[\ P[{1, 2}], P[{1, 2, 3, 4, 5, 6}]\ ]\ ]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(720\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since  ",
  StyleBox["6! = 720",
    FontFamily->"cmti12",
    FontSize->14,
    FontVariations->{"CompatibilityType"->0}],
  "  , they",
  StyleBox[" ",
    FontWeight->"Bold"],
  " do generate ",
  Cell[BoxData[
      \(TraditionalForm\`S\_6\)]],
  "."
}], "Text",
  FontSize->14],

Cell[TextData[{
  "Let's look for generators of ",
  Cell[BoxData[
      \(TraditionalForm\`A\_4\)]],
  ", which is also not cyclic. We know that the even permutations of degree 4 \
are the 3-cycles, the products of 2 disjoint transpositions and the identity. \
We first try two 3-cycles:"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Order[\ Group[\ P[{1, 2, 3}], P[{2, 3, 4}]\ ]\ ]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(12\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "It is not hard to show that the order of ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " is n!/2 (see exercise 3.11). Therefore",
  " ",
  StyleBox["the two 3-cycles",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" ",
    FontWeight->"Bold"],
  "do generate",
  StyleBox[" ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`A\_4\)]],
  ". How about a 3-cycle and a product of two disjoint transpositions?"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Order[\ Group[\ P[{1, 2, 3}], P[{1, 2}, {3, 4}]\ ]\ ]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(12\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "These two appear to generate ",
  Cell[BoxData[
      \(TraditionalForm\`A\_4\)]],
  "as well. Let's see how these calculations extend to ",
  Cell[BoxData[
      \(TraditionalForm\`A\_5\)]],
  ". We could use two 3-cycles again. But that would not work in ",
  Cell[BoxData[
      \(TraditionalForm\`A\_6\)]],
  ". So we shall try with a 5-cycle and a 3-cycle:"
}], "Text",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Order[\ Group[\ P[{1, 2, 3, 4, 5}], \ P[{1, 2, 3}]\ ]\ ]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(60\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "And 60 is the order of ",
  Cell[BoxData[
      \(TraditionalForm\`A\_5\)]],
  ". We now try 5-cycle and a product of two disjoint transpositions;"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Order[Group[P[{1, 2, 3, 4, 5}], \ P[{1, 2}, {3, 4}]]]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(60\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This works too. Do these calculations extend to ",
  Cell[BoxData[
      \(TraditionalForm\`A\_6\)]],
  "? Do they generalize to ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  ", for arbitrary n?"
}], "Text",
  FontSize->14]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowSize->{586, 719},
WindowMargins->{{Automatic, 20}, {Automatic, 4}},
MacintoshSystemPageSetup->"\<\
02P0001804P000000^L2D_ogooL33`9K8085:0?l0000005X0FP000003X<;VP5d
038;VTRX04/00@4100000BL?00400@000000000000000000000000000040I0<0
00000000000@8P404@000000000eC64P\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 55, 0, 50, "Section"],
Cell[1797, 53, 295, 9, 50, "Text"],
Cell[2095, 64, 74, 2, 28, "Input"],
Cell[2172, 68, 385, 12, 70, "Text"],
Cell[2560, 82, 250, 10, 65, "Text"],
Cell[2813, 94, 108, 3, 32, "Text"],
Cell[2924, 99, 154, 5, 32, "Text"],
Cell[3081, 106, 98, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[3204, 112, 352, 14, 30, "Input"],
Cell[3559, 128, 229, 6, 39, "Output"]
}, Open  ]],
Cell[3803, 137, 323, 14, 34, "Text"],
Cell[4129, 153, 143, 5, 32, "Text"],
Cell[4275, 160, 82, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[4382, 166, 106, 3, 28, "Input"],
Cell[4491, 171, 229, 6, 39, "Output"]
}, Open  ]],
Cell[4735, 180, 81, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[4841, 186, 54, 2, 30, "Input"],
Cell[4898, 190, 229, 6, 39, "Output"]
}, Open  ]],
Cell[5142, 199, 201, 9, 34, "Text"],

Cell[CellGroupData[{
Cell[5368, 212, 89, 3, 28, "Input"],
Cell[5460, 217, 229, 6, 39, "Output"]
}, Open  ]],
Cell[5704, 226, 270, 7, 52, "Text"],
Cell[5977, 235, 141, 4, 32, "Text"],
Cell[6121, 241, 129, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[6275, 249, 694, 25, 30, "Input"],
Cell[6972, 276, 45, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7054, 282, 432, 14, 28, "Input"],
Cell[7489, 298, 48, 1, 26, "Output"]
}, Open  ]],
Cell[7552, 302, 321, 8, 104, "Text"],

Cell[CellGroupData[{
Cell[7898, 314, 64, 2, 28, "Input"],
Cell[7965, 318, 1000, 26, 70, "Output"]
}, Open  ]],
Cell[8980, 347, 141, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[9146, 355, 164, 3, 46, "Input"],
Cell[9313, 360, 1185, 32, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10535, 397, 59, 2, 28, "Input"],
Cell[10597, 401, 1185, 32, 70, "Output"]
}, Open  ]],
Cell[11797, 436, 34, 1, 32, "Text"],
Cell[11834, 439, 472, 16, 47, "Text"],
Cell[12309, 457, 207, 9, 34, "Text"],
Cell[12519, 468, 780, 23, 91, "Text"],

Cell[CellGroupData[{
Cell[13324, 495, 107, 2, 28, "Input"],
Cell[13434, 499, 107, 2, 26, "Output"]
}, Open  ]],
Cell[13556, 504, 216, 7, 34, "Text"],

Cell[CellGroupData[{
Cell[13797, 515, 60, 2, 28, "Input"],
Cell[13860, 519, 185, 3, 41, "Output"]
}, Open  ]],
Cell[14060, 525, 233, 9, 34, "Text"],

Cell[CellGroupData[{
Cell[14318, 538, 92, 3, 30, "Input"],
Cell[14413, 543, 63, 1, 26, "Output"]
}, Open  ]],
Cell[14491, 547, 162, 6, 34, "Text"],

Cell[CellGroupData[{
Cell[14678, 557, 57, 2, 28, "Input"],
Cell[14738, 561, 36, 1, 26, "Output"]
}, Open  ]],
Cell[14789, 565, 309, 12, 32, "Text"],

Cell[CellGroupData[{
Cell[15123, 581, 103, 2, 28, "Input"],
Cell[15229, 585, 37, 1, 26, "Output"]
}, Open  ]],
Cell[15281, 589, 301, 14, 36, "Text"],
Cell[15585, 605, 317, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[15927, 617, 97, 2, 28, "Input"],
Cell[16027, 621, 36, 1, 26, "Output"]
}, Open  ]],
Cell[16078, 625, 520, 18, 52, "Text"],

Cell[CellGroupData[{
Cell[16623, 647, 102, 2, 28, "Input"],
Cell[16728, 651, 36, 1, 26, "Output"]
}, Open  ]],
Cell[16779, 655, 409, 12, 74, "Text"],

Cell[CellGroupData[{
Cell[17213, 671, 105, 2, 28, "Input"],
Cell[17321, 675, 36, 1, 26, "Output"]
}, Open  ]],
Cell[17372, 679, 194, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[17591, 689, 102, 2, 28, "Input"],
Cell[17696, 693, 36, 1, 26, "Output"]
}, Open  ]],
Cell[17747, 697, 252, 9, 32, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

