(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15437,        596]*)
(*NotebookOutlinePosition[     16280,        623]*)
(*  CellTagsIndexPosition[     16236,        619]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Chapter 8: Software and Calculations", "Section"],

Cell[TextData[{
  "The function  ",
  StyleBox["Orbit[G,x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  will compute the orbit of ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " under the permutation group or\nlinear group ",
  StyleBox["G",
    FontWeight->"Bold"],
  ". Here ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a positive natural number or a vector. For\nexample, "
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(A5\  = \ Group[P[{1, 2, 3}]\ , \ P[{3, 4, 5}]]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2 3)", "(3 4 5)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "So the orbit of 2 under ",
  Cell[BoxData[
      \(TraditionalForm\`A\_5\)]],
  " can be computed by"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Orbit[A5, \ 2]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \({2, 3, 1, 4, 5}\)], "Output"]
}, Open  ]],

Cell["Similarly, if you set ", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ChoosePrime[5]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(5\)], "Output"]
}, Open  ]],

Cell["and take", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(F20 = Group[L[{1, 1}, {0, 1}]\ , \ L[{2, 0}, {0, 3}]]\)], "Input",
  FontSize->14],

Cell[BoxData[
    RowBox[{"\[LeftAngleBracket]", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1"},
                {"0", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "0"},
                {"0", "3"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "\[RightAngleBracket]"}]], "Output"]
}, Open  ]],

Cell["then the orbit of the vector (2,3) is", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Orbit[F20, {2, 3}]\)], "Input",
  FontSize->14],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2"},
                {"3"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {2, 3}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0"},
                {"3"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {0, 3}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0"},
                {"4"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {0, 4}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0"},
                {"2"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {0, 2}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0"},
                {"1"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {0, 1}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1"},
                {"1"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {1, 1}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2"},
                {"1"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {2, 1}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2"},
                {"2"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {2, 2}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"3"},
                {"1"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {3, 1}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1"},
                {"3"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {1, 3}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2"},
                {"4"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {2, 4}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1"},
                {"4"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {1, 4}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"3"},
                {"3"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {3, 3}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"4"},
                {"1"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {4, 1}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"4"},
                {"2"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {4, 2}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1"},
                {"2"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {1, 2}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"3"},
                {"2"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {3, 2}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"4"},
                {"3"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {4, 3}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"3"},
                {"4"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {3, 4}]], ",", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"4"},
                {"4"}
                }], "\[NoBreak]", ")"}],
          MatrixForm[ {4, 4}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["(see exercise 4.4). ",
    FontFamily->"Courier",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Stabilizer[G,x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will compute the stabilizer of ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the group ",
  StyleBox["G",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " . So for example"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Stabilizer[A5, 3]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2 4)", "(1 2 5)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The conjugacy class of an element can be calculated with the function  ",
  StyleBox["ConjugacyClass.",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "Let's use it to compute the conjugacy classes in ",
  Cell[BoxData[
      \(TraditionalForm\`A\_5\)]],
  ".  To begin, we know that the conjugacy classes in ",
  Cell[BoxData[
      \(TraditionalForm\`S\_5\)]],
  "correspond to the cycle types of permutations of degree 5. The even cycle \
types are"
}], "Text",
  FontSize->14],

Cell["{1}, {3}, {5}, {2,2} .", "Text",
  TextAlignment->Center,
  FontSize->14],

Cell[TextData[{
  "The function  ",
  StyleBox["CycleTypes",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " computes the number of permutations in each cycle type:"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(CycleTypes[A5]\)], "Input",
  FontSize->14],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"{1}\"\>", "\<\"{3}\"\>", "\<\"{5}\"\>", "\<\"{2, 2}\"\>"},
          {"1", "20", "24", "15"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now two elements in ",
  Cell[BoxData[
      \(TraditionalForm\`A\_5\)]],
  "may be conjugate by an element in ",
  Cell[BoxData[
      \(TraditionalForm\`S\_5\)]],
  " but not by an element in ",
  Cell[BoxData[
      \(TraditionalForm\`A\_5\)]],
  ". So a conjugacy class of ",
  Cell[BoxData[
      \(TraditionalForm\`S\_5\)]],
  "may break up into more than one conjugacy class in ",
  Cell[BoxData[
      \(TraditionalForm\`A\_5\)]],
  ". We begin with a 3-cycle:"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConjugacyClass[A5, \ P[{1, 2, 3}]]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \({"(1 2 3)", "(1 2 4)", "(1 2 5)", "(2 3 4)", "(1 4 3)", "(1 5 4)", 
      "(1 3 5)", "(1 5 2)", "(1 3 2)", "(1 4 2)", "(2 3 5)", "(1 5 3)", 
      "(1 3 4)", "(1 4 5)", "(2 4 3)", "(2 4 5)", "(2 5 3)", "(2 5 4)", 
      "(3 4 5)", "(3 5 4)"}\)], "Output"]
}, Open  ]],

Cell["\<\
These are all 20 3-cycles. Next we look at the conjugacy class of a \
5-cycle:\
\>", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConjugacyClass[A5, \ P[{1, 2, 3, \ 4, \ 5}]]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \({"(1 2 3 4 5)", "(1 2 4 5 3)", "(1 2 5 3 4)", "(1 4 2 3 5)", 
      "(1 4 5 2 3)", "(1 5 2 4 3)", "(1 3 2 5 4)", "(1 3 5 4 2)", 
      "(1 4 3 5 2)", "(1 5 3 2 4)", "(1 3 4 2 5)", "(1 5 4 3 2)"}\)], "Output"]
}, Open  ]],

Cell["\<\
This is only half of the 5-cycles! One that is missing is  (1 2 3 5 \
4) . So let's compute its conjugacy class:\
\>", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConjugacyClass[A5, \ P[{1, 2, 3, 5, \ 4}]]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \({"(1 2 3 5 4)", "(1 2 4 3 5)", "(1 2 5 4 3)", "(1 5 2 3 4)", 
      "(1 3 2 4 5)", "(1 3 4 5 2)", "(1 4 2 5 3)", "(1 4 5 3 2)", 
      "(1 5 3 4 2)", "(1 4 3 2 5)", "(1 3 5 2 4)", "(1 5 4 2 3)"}\)], "Output"]
}, Open  ]],

Cell["\<\
These are the remaining 5-cycles. Lastly we look at the conjugacy \
class of a product of two transpositions:\
\>", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConjugacyClass[A5, \ P[{1, 2}, {3, 4}]]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \({"(1 2)(3 4)", "(1 2)(4 5)", "(1 2)(3 5)", "(1 4)(2 3)", "(1 3)(2 4)", 
      "(1 4)(2 5)", "(1 5)(2 3)", "(1 3)(2 5)", "(1 5)(2 4)", "(2 3)(4 5)", 
      "(1 3)(4 5)", "(1 4)(3 5)", "(1 5)(3 4)", "(2 4)(3 5)", 
      "(2 5)(3 4)"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "These are all 15 permutations of type {2, 2}. So these four sets together \
with {(1)} are the conjugacy classes of ",
  Cell[BoxData[
      \(TraditionalForm\`A\_5\)]],
  "."
}], "Text",
  FontSize->14],

Cell[TextData[{
  "\tThe centre of a group can be computed with the function  ",
  StyleBox["Centre",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " . For example,"
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(D4\  = \ Group[P[{1, \ 2, \ 3, \ 4}], \ P[{1, \ 3}]]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 2 3 4)", "(1 3)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell["and", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(Centre[D4]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(\[LeftAngleBracket]"(1 3)(2 4)"\[RightAngleBracket]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tFor a matrix \[Alpha] in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(GL\)\((\)\(2, \
\[DoubleStruckCapitalF]\_p\)\)\)]],
  ") the corresponding linear fractional transformation  ",
  Cell[BoxData[
      \(TraditionalForm\`s\_\[Alpha]\)]],
  " is computed by the function",
  StyleBox[" ",
    FontFamily->"Courier"],
  StyleBox["FL",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["TPermutation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " . Let's repeat the calculation of \n\t\n\t\t\t\t\t",
  Cell[BoxData[
      \(TraditionalForm\`f\_3\)]],
  ":  GL(2,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalF]\_3\)]],
  ") \[LongRightArrow] ",
  Cell[BoxData[
      \(TraditionalForm\`S\_4\)]],
  " \n\nusing this function:"
}], "Text",
  TextAlignment->Left,
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ChoosePrime[3]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a\  = \ L[{2, 1}, {0, 1}]\)], "Input",
  FontSize->14],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2", "1"},
            {"0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\  = \ L[{2, 2}, {0, 1}]\)], "Input",
  FontSize->14],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2", "2"},
            {"0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(c\  = \ L[{0, 1}, {1, 0}]\)], "Input",
  FontSize->14],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "1"},
            {"1", "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FLTPermutation[a]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \("(1 0)"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FLTPermutation[b]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \("(2 0)"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FLTPermutation[c]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \("(0 \[Infinity])"\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowSize->{596, 719},
WindowMargins->{{Automatic, 7}, {Automatic, 5}},
MacintoshSystemPageSetup->"\<\
00P0001804P000000]/2@?oWonh2o`9B7`<5:0?l0040004/0B`000002nL9H04/
02d5X5k/02H20@4101P00BL?00400@0000000000000000010000000000000000
0000000000000002000000@210D00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 55, 0, 50, "Section"],
Cell[1797, 53, 478, 18, 70, "Text"],

Cell[CellGroupData[{
Cell[2300, 75, 95, 2, 28, "Input"],
Cell[2398, 79, 93, 1, 26, "Output"]
}, Open  ]],
Cell[2506, 83, 148, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[2679, 93, 63, 2, 28, "Input"],
Cell[2745, 97, 49, 1, 26, "Output"]
}, Open  ]],
Cell[2809, 101, 54, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[2888, 106, 63, 2, 28, "Input"],
Cell[2954, 110, 35, 1, 26, "Output"]
}, Open  ]],
Cell[3004, 114, 40, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[3069, 119, 102, 2, 28, "Input"],
Cell[3174, 123, 487, 14, 39, "Output"]
}, Open  ]],
Cell[3676, 140, 69, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[3770, 145, 67, 2, 28, "Input"],
Cell[3840, 149, 4020, 122, 70, "Output"]
}, Open  ]],
Cell[7875, 274, 450, 17, 50, "Text"],

Cell[CellGroupData[{
Cell[8350, 295, 66, 2, 28, "Input"],
Cell[8419, 299, 93, 1, 26, "Output"]
}, Open  ]],
Cell[8527, 303, 506, 14, 68, "Text"],
Cell[9036, 319, 79, 2, 32, "Text"],
Cell[9118, 323, 201, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[9344, 334, 63, 2, 28, "Input"],
Cell[9410, 338, 311, 9, 39, "Output"]
}, Open  ]],
Cell[9736, 350, 516, 18, 68, "Text"],

Cell[CellGroupData[{
Cell[10277, 372, 83, 2, 28, "Input"],
Cell[10363, 376, 275, 4, 56, "Output"]
}, Open  ]],
Cell[10653, 383, 118, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[10796, 391, 93, 2, 28, "Input"],
Cell[10892, 395, 228, 3, 56, "Output"]
}, Open  ]],
Cell[11135, 401, 152, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[11312, 409, 91, 2, 28, "Input"],
Cell[11406, 413, 228, 3, 56, "Output"]
}, Open  ]],
Cell[11649, 419, 149, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[11823, 427, 88, 2, 28, "Input"],
Cell[11914, 431, 265, 4, 56, "Output"]
}, Open  ]],
Cell[12194, 438, 222, 7, 50, "Text"],
Cell[12419, 447, 201, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[12645, 458, 101, 2, 28, "Input"],
Cell[12749, 462, 93, 1, 26, "Output"]
}, Open  ]],
Cell[12857, 466, 35, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[12917, 471, 59, 2, 28, "Input"],
Cell[12979, 475, 85, 1, 26, "Output"]
}, Open  ]],
Cell[13079, 479, 844, 29, 122, "Text"],

Cell[CellGroupData[{
Cell[13948, 512, 63, 2, 28, "Input"],
Cell[14014, 516, 35, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14086, 522, 74, 2, 28, "Input"],
Cell[14163, 526, 189, 6, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14389, 537, 74, 2, 28, "Input"],
Cell[14466, 541, 189, 6, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14692, 552, 74, 2, 28, "Input"],
Cell[14769, 556, 189, 6, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14995, 567, 66, 2, 28, "Input"],
Cell[15064, 571, 41, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15142, 577, 66, 2, 28, "Input"],
Cell[15211, 581, 41, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15289, 587, 66, 2, 28, "Input"],
Cell[15358, 591, 51, 1, 26, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

